@@ -4,22 +4,24 @@
 from distutils.core import setup
 import glob, sys, py2exe, os
 
-sys.path.append('..')
+sys.path.insert(0, '..')
 
 sys.argv.extend("py2exe --bundle 1".split())
 
+import serial.tools.miniterm
+
 setup(
-    name='miniterm',
-    #~ version='0.5',
-    zipfile=None,
+    name = 'miniterm',
+    zipfile = None,
     options = {"py2exe":
         {
             'dist_dir': 'bin',
-            'excludes': ['javax.comm'],
+            'excludes': ['serialjava', 'serialposix', 'serialcli'],
+            'compressed': 1,
         }
     },
     console = [
-        #~ "miniterm_exe_wrapper.py",
-        "miniterm.py",
+        #~ "miniterm.py",
+        serial.tools.miniterm.__file__
     ],
 )
